"use strict";var a=function(e,r){return function(){return r||e((r={exports:{}}).exports,r),r.exports}};var u=a(function(y,f){
var s=require('@stdlib/assert-is-array/dist'),o=require('@stdlib/error-tools-fmtprodmsg/dist');function l(e){if(typeof e!="function")throw new TypeError(o('0BB3J',e));return r;function r(t){var i,n;if(!s(t)||(i=t.length,i===0))return!1;for(n=0;n<i;n++)if(e(t[n])===!1)return!1;return!0}}f.exports=l
});var v=u();module.exports=v;
/** @license Apache-2.0 */
//# sourceMappingURL=index.js.map
